=========
Notebooks
=========

You can find here the companion notebooks that describe the experiments of our papers.

.. toctree::

    termination
    corsorts
    profiles
    examples_with_a_chain_and_a_y_shape
